import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixAppSettingsV1Settings from './app-settings-v1-settings-app-settings.http.js';
/** The state of the settings (Saved or Published) */
export var State;
(function (State) {
    /** Not relevant */
    State["NR"] = "NR";
    State["SAVED"] = "SAVED";
    State["PUBLISHED"] = "PUBLISHED";
})(State || (State = {}));
/** The host in which the settings are displayed */
export var Host;
(function (Host) {
    Host["NA"] = "NA";
    Host["VIEWER"] = "VIEWER";
    Host["BUSINESS_MANAGER"] = "BUSINESS_MANAGER";
    Host["ONE_APP"] = "ONE_APP";
})(Host || (Host = {}));
/** scope of settings when creating/updating; */
export var Scope;
(function (Scope) {
    /** multiple instances of a tpa can share same settings; */
    Scope["APP"] = "APP";
    /** scoped to a single component of an app; */
    Scope["COMPONENT"] = "COMPONENT";
})(Scope || (Scope = {}));
/**
 * Set component settings by componentId
 * @param componentId - The component Id
 * @public
 * @documentationMaturity preview
 * @requiredField componentId
 * @fqn com.wix.fed.settings.AppSettingsService.SetComponentSettings
 */
export async function setComponentSettings(componentId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        componentId: componentId,
        settings: options?.settings,
        state: options?.state,
        host: options?.host,
        translations: options?.translations,
        states: options?.states,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.setComponentSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                componentId: '$[0]',
                settings: '$[1].settings',
                state: '$[1].state',
                host: '$[1].host',
                translations: '$[1].translations',
                states: '$[1].states',
            },
            singleArgumentUnchanged: false,
        }, ['componentId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Get component settings by componentId
 * @param componentId - The component we want data for. Component ids can be from the site or oneApp
 * @public
 * @documentationMaturity preview
 * @requiredField componentId
 * @fqn com.wix.fed.settings.AppSettingsService.GetComponentSettings
 */
export async function getComponentSettings(componentId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        componentId: componentId,
        state: options?.state,
        host: options?.host,
        languageKey: options?.languageKey,
        includeGlobalSettings: options?.includeGlobalSettings,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.getComponentSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                componentId: '$[0]',
                state: '$[1].state',
                host: '$[1].host',
                languageKey: '$[1].languageKey',
                includeGlobalSettings: '$[1].includeGlobalSettings',
            },
            singleArgumentUnchanged: false,
        }, ['componentId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Set global settings by instanceId (extracted from Authorization)
 * @public
 * @documentationMaturity preview
 * @fqn com.wix.fed.settings.AppSettingsService.SetGlobalSettings
 */
export async function setGlobalSettings(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        settings: options?.settings,
        componentSettings: options?.componentSettings,
        state: options?.state,
        host: options?.host,
        translations: options?.translations,
        states: options?.states,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.setGlobalSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                settings: '$[0].settings',
                componentSettings: '$[0].componentSettings',
                state: '$[0].state',
                host: '$[0].host',
                translations: '$[0].translations',
                states: '$[0].states',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Get global settings by instanceId (extracted from Authorization)
 * @public
 * @documentationMaturity preview
 * @fqn com.wix.fed.settings.AppSettingsService.GetGlobalSettings
 */
export async function getGlobalSettings(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        state: options?.state,
        host: options?.host,
        includeComponentSettings: options?.includeComponentSettings,
        languageKey: options?.languageKey,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.getGlobalSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                state: '$[0].state',
                host: '$[0].host',
                includeComponentSettings: '$[0].includeComponentSettings',
                languageKey: '$[0].languageKey',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=app-settings-v1-settings-app-settings.universal.js.map